@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.001003';
+our $VERSION = '2.002000';
 
 1;
 
@@ -20,7 +20,7 @@ GeoIP2 - Perl API for MaxMind's GeoIP2 web services and databases
 
 =head1 VERSION
 
-version 2.001003
+version 2.002000
 
 =head1 DESCRIPTION
 
@@ -112,16 +112,34 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
+
 Olaf Alders <oalders@maxmind.com>
 
 =back
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Graham Knop
+=for stopwords Andy Jack Graham Knop Mateu X Hunter
+
+=over 4
+
+=item *
+
+Andy Jack <github@veracity.ca>
+
+=item *
 
 Graham Knop <haarg@haarg.org>
 
+=item *
+
+Mateu X Hunter <hunter@missoula.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 - 2015 by MaxMind, Inc..
