@@ -3,7 +3,7 @@ package GeoIP2::Model::Insights;
 use strict;
 use warnings;
 
-our $VERSION = '2.001003';
+our $VERSION = '2.002000';
 
 use GeoIP2::Types qw( HashRef object_isa_type );
 use Sub::Quote qw( quote_sub );
@@ -28,7 +28,7 @@ GeoIP2::Model::Insights - Model class for GeoIP2 Precision: Insights
 
 =head1 VERSION
 
-version 2.001003
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -57,12 +57,11 @@ L<http://dev.maxmind.com/geoip/geoip2/web-services> for more details.
 
 =head1 METHODS
 
-This class provides the following methods, each of which returns a record
-object.
+This class provides the following methods.
 
 =head2 $insights->city()
 
-Returns a L<GeoIP2::Record::City> object representing country data for the
+Returns a L<GeoIP2::Record::City> object representing city data for the
 requested IP address.
 
 =head2 $insights->continent()
@@ -78,7 +77,7 @@ believes the IP is located.
 
 =head2 $insights->location()
 
-Returns a L<GeoIP2::Record::Location> object representing country data for the
+Returns a L<GeoIP2::Record::Location> object representing location data for the
 requested IP address.
 
 =head2 $insights->maxmind()
@@ -146,6 +145,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
+
 Olaf Alders <oalders@maxmind.com>
 
 =back
