@@ -3,7 +3,7 @@ package GeoIP2::Record::Location;
 use strict;
 use warnings;
 
-our $VERSION = '2.001003';
+our $VERSION = '2.002000';
 
 use GeoIP2::Types qw( NonNegativeInt Num PositiveInt Str );
 
@@ -15,6 +15,12 @@ has accuracy_radius => (
     predicate => 'has_accuracy_radius',
 );
 
+has average_income => (
+    is        => 'ro',
+    isa       => NonNegativeInt,
+    predicate => 'has_average_income',
+);
+
 has latitude => (
     is        => 'ro',
     isa       => Num,
@@ -33,6 +39,12 @@ has metro_code => (
     predicate => 'has_metro_code',
 );
 
+has population_density => (
+    is        => 'ro',
+    isa       => NonNegativeInt,
+    predicate => 'has_population_density',
+);
+
 has time_zone => (
     is        => 'ro',
     isa       => Str,
@@ -53,7 +65,7 @@ GeoIP2::Record::Location - Contains data for the location record associated with
 
 =head1 VERSION
 
-version 2.001003
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -88,6 +100,13 @@ IP address is likely to be.
 
 This attribute is only available from the Insights end point.
 
+=head2 $location_rec->average_income()
+
+This returns a non-negative integer representing the average income in US
+dollars associated with the requested IP address.
+
+This attribute is only available from the Insights end point.
+
 =head2 $location_rec->latitude()
 
 This returns the latitude of the location as a floating point number.
@@ -108,6 +127,13 @@ MaxMind returns the same metro codes as the Google AdWords API
 
 This attribute is returned by all end points except the Country end point.
 
+=head2 $location_rec->population_density()
+
+Returns a non-negative integer representing the estimated population per square
+kilometer associated with the requested IP address.
+
+This attribute is only available from the Insights end point.
+
 =head2 $location_rec->time_zone()
 
 This returns the time zone associated with a location, as specified by the IANA
@@ -129,6 +155,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
+
 Olaf Alders <oalders@maxmind.com>
 
 =back
