@@ -3,7 +3,7 @@ package GeoIP2::Record::Traits;
 use strict;
 use warnings;
 
-our $VERSION = '2.001003';
+our $VERSION = '2.002000';
 
 use GeoIP2::Types qw( Bool BoolCoercion IPAddress NonNegativeInt Str );
 use Sub::Quote qw( quote_sub );
@@ -76,7 +76,7 @@ GeoIP2::Record::Traits - Contains data for the traits record associated with an
 
 =head1 VERSION
 
-version 2.001003
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -141,15 +141,16 @@ This attribute is returned by all end points.
 
 =head2 $traits_rec->is_anonymous_proxy()
 
-This returns true if the IP is an anonymous proxy. See
-L<http://dev.maxmind.com/faq/geoip#anonproxy> for further details.
+I<Deprecated.> Please see our L<GeoIP2 Anonymous IP
+database|https://www.maxmind.com/en/geoip2-anonymous-ip-database> to
+determine whether the IP address is used by an anonymizing service.
 
 This attribute is returned by all end points.
 
 =head2 $traits_rec->is_satellite_provider()
 
-This returns true if the IP is a from a satellite provider that provides
-service to multiple countries.
+I<Deprecated.> Please see our L<GeoIP2 Anonymous IP
+database|https://www.maxmind.com/en/geoip2-anonymous-ip-database>.
 
 This attribute is returned by all end points.
 
@@ -222,6 +223,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
+
 Olaf Alders <oalders@maxmind.com>
 
 =back
