@@ -3,7 +3,7 @@ package GeoIP2::Types;
 use strict;
 use warnings;
 
-our $VERSION = '2.001003';
+our $VERSION = '2.002000';
 
 use Data::Validate::IP ();
 use GeoIP2::Error::Type;
@@ -64,6 +64,7 @@ sub BoolCoercion () {
                && ( $_[0]->isa('JSON::Boolean')
                     || $_[0]->isa('JSON::PP::Boolean')
                     || $_[0]->isa('JSON::XS::Boolean')
+                    || $_[0]->isa('Cpanel::JSON::XS::Boolean')
                   )
                 ? $_[0] + 0 : $_[0] }
     );
@@ -116,8 +117,7 @@ sub JSONObject () {
     sub LocalesArrayRef () {
         return quote_sub(
             q{ GeoIP2::Types::_tc_fail( $_[0], 'LocalesArrayRef' )
-                   unless defined $_[0]
-                   && ref $_[0]
+                   unless ref $_[0]
                    && Scalar::Util::reftype( $_[0] ) eq 'ARRAY'
                    && !Scalar::Util::blessed( $_[0] )
                    && List::MoreUtils::all(
@@ -149,17 +149,14 @@ sub MaxMindLicenseKey () {
 sub MaybeStr () {
     return quote_sub(
         q{ GeoIP2::Types::_tc_fail( $_[0], 'StrOrUndef' )
-               unless !defined $_[0]
-               || ( defined $_[0]
-               && !ref $_[0] ); }
+               unless !ref $_[0]; }
     );
 }
 
 sub NameHashRef () {
     return quote_sub(
         q{ GeoIP2::Types::_tc_fail( $_[0], 'NameHashRef' )
-               unless defined $_[0]
-               && ref $_[0]
+               unless ref $_[0]
                && Scalar::Util::reftype( $_[0] ) eq 'HASH'
                && ! Scalar::Util::blessed( $_[0] )
                && &List::MoreUtils::all( sub { defined $_ && ! ref $_ }, values %{ $_[0] } ); }
