@@ -5,7 +5,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.001003';
+our $VERSION = '2.002000';
 
 use Data::Validate::IP 0.19 qw( is_public_ipv4 is_public_ipv6 );
 use GeoIP2::Error::Generic;
@@ -19,7 +19,7 @@ use GeoIP2::Types
     qw( JSONObject MaxMindID MaxMindLicenseKey Str URIObject UserAgentObject );
 use HTTP::Headers;
 use HTTP::Request;
-use JSON;
+use JSON::MaybeXS;
 use MIME::Base64 qw( encode_base64 );
 use LWP::Protocol::https;
 use LWP::UserAgent;
@@ -68,7 +68,7 @@ has _json => (
     is       => 'ro',
     isa      => JSONObject,
     init_arg => undef,
-    default  => quote_sub(q{ JSON->new()->utf8() }),
+    default  => quote_sub(q{ JSON::MaybeXS->new(utf8 => 1) }),
 );
 
 sub BUILD {
@@ -315,7 +315,7 @@ GeoIP2::WebService::Client - Perl API for the GeoIP2 Precision web services
 
 =head1 VERSION
 
-version 2.001003
+version 2.002000
 
 =head1 SYNOPSIS
 
@@ -556,6 +556,10 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =item *
 
+Mark Fowler <mfowler@maxmind.com>
+
+=item *
+
 Olaf Alders <oalders@maxmind.com>
 
 =back
